==> pdf-model-arlington-1.29.7-sources.jar: org/verapdf/model/alayer/AStructureAttributesDict.java <==
/**
 * This file is part of VeraPDF Validation Model API for Arlington PDF Model, a module of the veraPDF project.
 * Copyright (c) 2015-2025, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * VeraPDF Validation Model API for Arlington PDF Model is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AStructureAttributesDict extends AObject {
	
















	/**
	*/
	public Boolean getcontainsBBox();

	/**
	*/
	public String getBBoxType();

	/**
	*/
	public Boolean getBBoxHasTypeRectangle();

	/**
	*/
	public Boolean getcontainsBackgroundColor();

	/**
	*/
	public String getBackgroundColorType();

	/**
	*/
	public Boolean getBackgroundColorHasTypeArray();

	/**
	*/
	public Boolean getcontainsBaselineShift();

	/**
	*/
	public String getBaselineShiftType();

	/**
	*/
	public Boolean getBaselineShiftHasTypeNumber();

	/**
	*/
	public Boolean getcontainsBlockAlign();

	/**
	*/
	public String getBlockAlignType();

	/**
	*/
	public Boolean getBlockAlignHasTypeName();

	/**
	*/
	public String getBlockAlignNameValue();

	/**
	*/
	public Boolean getcontainsBorderColor();

	/**
	*/
	public String getBorderColorType();

	/**
	*/
	public Boolean getBorderColorHasTypeArray();

	/**
	*/
	public Boolean getcontainsBorderStyle();

	/**
	*/
	public String getBorderStyleType();

	/**
	*/
	public Boolean getBorderStyleHasTypeArray();

	/**
	*/
	public Boolean getBorderStyleHasTypeName();

	/**
	*/
	public String getBorderStyleNameValue();

	/**
	*/
	public Boolean getcontainsBorderThickness();

	/**
	*/
	public String getBorderThicknessType();

	/**
	*/
	public Boolean getBorderThicknessHasTypeArray();

	/**
	*/
	public Boolean getBorderThicknessHasTypeNumber();

	/**
	*/
	public Boolean getcontainsChecked();

	/**
	*/
	public String getCheckedType();

	/**
	*/
	public Boolean getCheckedHasTypeName();

	/**
	*/
	public String getCheckedNameValue();

	/**
	*/
	public Boolean getcontainsColSpan();

	/**
	*/
	public String getColSpanType();

	/**
	*/
	public Boolean getColSpanHasTypeInteger();

	/**
	*/
	public Boolean getcontainsColor();

	/**
	*/
	public String getColorType();

	/**
	*/
	public Boolean getColorHasTypeArray();

	/**
	*/
	public Boolean getcontainsColumnCount();

	/**
	*/
	public String getColumnCountType();

	/**
	*/
	public Boolean getColumnCountHasTypeInteger();

	/**
	*/
	public Boolean getcontainsColumnGap();

	/**
	*/
	public String getColumnGapType();

	/**
	*/
	public Boolean getColumnGapHasTypeArray();

	/**
	*/
	public Boolean getColumnGapHasTypeNumber();

	/**
	*/
	public Boolean getcontainsColumnWidths();

	/**
	*/
	public String getColumnWidthsType();

	/**
	*/
	public Boolean getColumnWidthsHasTypeArray();

	/**
	*/
	public Boolean getColumnWidthsHasTypeNumber();

	/**
	*/
	public Boolean getcontainsContents();

	/**
	*/
	public String getContentsType();

	/**
	*/
	public Boolean getContentsHasTypeArray();

	/**
	*/
	public Boolean getContentsHasTypeStringText();

	/**
	*/
	public Boolean getcontainsContinuedForm();

	/**
	*/
	public String getContinuedFormType();

	/**
	*/
	public Boolean getContinuedFormHasTypeStringByte();

	/**
	*/
	public Boolean getcontainsContinuedList();

	/**
	*/
	public String getContinuedListType();

	/**
	*/
	public Boolean getContinuedListHasTypeBoolean();

	/**
	*/
	public Boolean getcontainsDesc();

	/**
	*/
	public String getDescType();

	/**
	*/
	public Boolean getDescHasTypeStringText();

	/**
	*/
	public Boolean getcontainsEndIndent();

	/**
	*/
	public String getEndIndentType();

	/**
	*/
	public Boolean getEndIndentHasTypeNumber();

	/**
	*/
	public Boolean getcontainsGlyphOrientationVertical();

	/**
	*/
	public String getGlyphOrientationVerticalType();

	/**
	*/
	public Boolean getGlyphOrientationVerticalHasTypeInteger();

	/**
	*/
	public Boolean getGlyphOrientationVerticalHasTypeName();

	/**
	*/
	public Long getGlyphOrientationVerticalIntegerValue();

	/**
	*/
	public String getGlyphOrientationVerticalNameValue();

	/**
	*/
	public Boolean getcontainsHeaders();

	/**
	*/
	public String getHeadersType();

	/**
	*/
	public Boolean getHeadersHasTypeArray();

	/**
	*/
	public Boolean getcontainsHeight();

	/**
	*/
	public String getHeightType();

	/**
	*/
	public Boolean getHeightHasTypeName();

	/**
	*/
	public Boolean getHeightHasTypeNumber();

	/**
	*/
	public Boolean getcontainsInlineAlign();

	/**
	*/
	public String getInlineAlignType();

	/**
	*/
	public Boolean getInlineAlignHasTypeName();

	/**
	*/
	public String getInlineAlignNameValue();

	/**
	*/
	public Boolean getcontainsLineHeight();

	/**
	*/
	public String getLineHeightType();

	/**
	*/
	public Boolean getLineHeightHasTypeName();

	/**
	*/
	public Boolean getLineHeightHasTypeNumber();

	/**
	*/
	public String getLineHeightNameValue();

	/**
	*/
	public Boolean getcontainsListNumbering();

	/**
	*/
	public String getListNumberingType();

	/**
	*/
	public Boolean getListNumberingHasTypeName();

	/**
	*/
	public String getListNumberingNameValue();

	/**
	*/
	public Boolean getcontainsNS();

	/**
	*/
	public Boolean getisNSIndirect();

	/**
	*/
	public String getNSType();

	/**
	*/
	public Boolean getNSHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsNoteType();

	/**
	*/
	public String getNoteTypeType();

	/**
	*/
	public Boolean getNoteTypeHasTypeName();

	/**
	*/
	public String getNoteTypeNameValue();

	/**
	*/
	public Boolean getcontainsO();

	/**
	*/
	public String getOType();

	/**
	*/
	public Boolean getOHasTypeName();

	/**
	*/
	public String getONameValue();

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public String getPType();

	/**
	*/
	public Boolean getPHasTypeArray();

	/**
	*/
	public Boolean getcontainsPadding();

	/**
	*/
	public String getPaddingType();

	/**
	*/
	public Boolean getPaddingHasTypeArray();

	/**
	*/
	public Boolean getPaddingHasTypeNumber();

	/**
	*/
	public Boolean getcontainsPlacement();

	/**
	*/
	public String getPlacementType();

	/**
	*/
	public Boolean getPlacementHasTypeName();

	/**
	*/
	public String getPlacementNameValue();

	/**
	*/
	public Boolean getcontainsRole();

	/**
	*/
	public String getRoleType();

	/**
	*/
	public Boolean getRoleHasTypeName();

	/**
	*/
	public String getRoleNameValue();

	/**
	*/
	public Boolean getcontainsRowSpan();

	/**
	*/
	public String getRowSpanType();

	/**
	*/
	public Boolean getRowSpanHasTypeInteger();

	/**
	*/
	public Boolean getcontainsRubyAlign();

	/**
	*/
	public String getRubyAlignType();

	/**
	*/
	public Boolean getRubyAlignHasTypeName();

	/**
	*/
	public String getRubyAlignNameValue();

	/**
	*/
	public Boolean getcontainsRubyPosition();

	/**
	*/
	public String getRubyPositionType();

	/**
	*/
	public Boolean getRubyPositionHasTypeName();

	/**
	*/
	public String getRubyPositionNameValue();

	/**
	*/
	public Boolean getcontainsScope();

	/**
	*/
	public String getScopeType();

	/**
	*/
	public Boolean getScopeHasTypeName();

	/**
	*/
	public String getScopeNameValue();

	/**
	*/
	public Boolean getcontainsShort();

	/**
	*/
	public String getShortType();

	/**
	*/
	public Boolean getShortHasTypeStringText();

	/**
	*/
	public Boolean getcontainsSpaceAfter();

	/**
	*/
	public String getSpaceAfterType();

	/**
	*/
	public Boolean getSpaceAfterHasTypeNumber();

	/**
	*/
	public Boolean getcontainsSpaceBefore();

	/**
	*/
	public String getSpaceBeforeType();

	/**
	*/
	public Boolean getSpaceBeforeHasTypeNumber();

	/**
	*/
	public Boolean getcontainsStartIndent();

	/**
	*/
	public String getStartIndentType();

	/**
	*/
	public Boolean getStartIndentHasTypeNumber();

	/**
	*/
	public Boolean getcontainsSubtype();

	/**
	*/
	public String getSubtypeType();

	/**
	*/
	public Boolean getSubtypeHasTypeName();

	/**
	*/
	public String getSubtypeNameValue();

	/**
	*/
	public Boolean getcontainsSummary();

	/**
	*/
	public String getSummaryType();

	/**
	*/
	public Boolean getSummaryHasTypeStringText();

	/**
	*/
	public Boolean getcontainsTBorderStyle();

	/**
	*/
	public String getTBorderStyleType();

	/**
	*/
	public Boolean getTBorderStyleHasTypeArray();

	/**
	*/
	public Boolean getTBorderStyleHasTypeName();

	/**
	*/
	public String getTBorderStyleNameValue();

	/**
	*/
	public Boolean getcontainsTPadding();

	/**
	*/
	public String getTPaddingType();

	/**
	*/
	public Boolean getTPaddingHasTypeArray();

	/**
	*/
	public Boolean getTPaddingHasTypeInteger();

	/**
	*/
	public Boolean getcontainsTextAlign();

	/**
	*/
	public String getTextAlignType();

	/**
	*/
	public Boolean getTextAlignHasTypeName();

	/**
	*/
	public String getTextAlignNameValue();

	/**
	*/
	public Boolean getcontainsTextDecorationColor();

	/**
	*/
	public String getTextDecorationColorType();

	/**
	*/
	public Boolean getTextDecorationColorHasTypeArray();

	/**
	*/
	public Boolean getcontainsTextDecorationThickness();

	/**
	*/
	public String getTextDecorationThicknessType();

	/**
	*/
	public Boolean getTextDecorationThicknessHasTypeNumber();

	/**
	*/
	public Boolean getcontainsTextDecorationType();

	/**
	*/
	public String getTextDecorationTypeType();

	/**
	*/
	public Boolean getTextDecorationTypeHasTypeName();

	/**
	*/
	public String getTextDecorationTypeNameValue();

	/**
	*/
	public Boolean getcontainsTextIndent();

	/**
	*/
	public String getTextIndentType();

	/**
	*/
	public Boolean getTextIndentHasTypeNumber();

	/**
	*/
	public Boolean getcontainsTextPosition();

	/**
	*/
	public String getTextPositionType();

	/**
	*/
	public Boolean getTextPositionHasTypeName();

	/**
	*/
	public String getTextPositionNameValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsWidth();

	/**
	*/
	public String getWidthType();

	/**
	*/
	public Boolean getWidthHasTypeName();

	/**
	*/
	public Boolean getWidthHasTypeNumber();

	/**
	*/
	public Boolean getcontainsWritingMode();

	/**
	*/
	public String getWritingModeType();

	/**
	*/
	public Boolean getWritingModeHasTypeName();

	/**
	*/
	public String getWritingModeNameValue();

	/**
	*/
	public Boolean getcontainschecked();

	/**
	*/
	public String getcheckedType();

	/**
	*/
	public Boolean getcheckedHasTypeName();

	/**
	*/
	public String getcheckedNameValue();
}

==> pdf-model-arlington-1.29.12-sources.jar: org/verapdf/model/alayer/AStructureAttributesDict.java <==
/**
 * This file is part of VeraPDF Validation Model API for Arlington PDF Model, a module of the veraPDF project.
 * Copyright (c) 2015-2025, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * VeraPDF Validation Model API for Arlington PDF Model is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AStructureAttributesDict extends AObject {
	
















	/**
	*/
	public Boolean getcontainsBBox();

	/**
	*/
	public String getBBoxType();

	/**
	*/
	public Boolean getBBoxHasTypeRectangle();

	/**
	*/
	public Boolean getcontainsBackgroundColor();

	/**
	*/
	public String getBackgroundColorType();

	/**
	*/
	public Boolean getBackgroundColorHasTypeArray();

	/**
	*/
	public Boolean getcontainsBaselineShift();

	/**
	*/
	public String getBaselineShiftType();

	/**
	*/
	public Boolean getBaselineShiftHasTypeNumber();

	/**
	*/
	public Boolean getcontainsBlockAlign();

	/**
	*/
	public String getBlockAlignType();

	/**
	*/
	public Boolean getBlockAlignHasTypeName();

	/**
	*/
	public String getBlockAlignNameValue();

	/**
	*/
	public Boolean getcontainsBorderColor();

	/**
	*/
	public String getBorderColorType();

	/**
	*/
	public Boolean getBorderColorHasTypeArray();

	/**
	*/
	public Boolean getcontainsBorderStyle();

	/**
	*/
	public String getBorderStyleType();

	/**
	*/
	public Boolean getBorderStyleHasTypeArray();

	/**
	*/
	public Boolean getBorderStyleHasTypeName();

	/**
	*/
	public String getBorderStyleNameValue();

	/**
	*/
	public Boolean getcontainsBorderThickness();

	/**
	*/
	public String getBorderThicknessType();

	/**
	*/
	public Boolean getBorderThicknessHasTypeArray();

	/**
	*/
	public Boolean getBorderThicknessHasTypeNumber();

	/**
	*/
	public Boolean getcontainsChecked();

	/**
	*/
	public String getCheckedType();

	/**
	*/
	public Boolean getCheckedHasTypeName();

	/**
	*/
	public String getCheckedNameValue();

	/**
	*/
	public Boolean getcontainsColSpan();

	/**
	*/
	public String getColSpanType();

	/**
	*/
	public Boolean getColSpanHasTypeInteger();

	/**
	*/
	public Boolean getcontainsColor();

	/**
	*/
	public String getColorType();

	/**
	*/
	public Boolean getColorHasTypeArray();

	/**
	*/
	public Boolean getcontainsColumnCount();

	/**
	*/
	public String getColumnCountType();

	/**
	*/
	public Boolean getColumnCountHasTypeInteger();

	/**
	*/
	public Boolean getcontainsColumnGap();

	/**
	*/
	public String getColumnGapType();

	/**
	*/
	public Boolean getColumnGapHasTypeArray();

	/**
	*/
	public Boolean getColumnGapHasTypeNumber();

	/**
	*/
	public Boolean getcontainsColumnWidths();

	/**
	*/
	public String getColumnWidthsType();

	/**
	*/
	public Boolean getColumnWidthsHasTypeArray();

	/**
	*/
	public Boolean getColumnWidthsHasTypeNumber();

	/**
	*/
	public Boolean getcontainsContents();

	/**
	*/
	public String getContentsType();

	/**
	*/
	public Boolean getContentsHasTypeArray();

	/**
	*/
	public Boolean getContentsHasTypeStringText();

	/**
	*/
	public Boolean getcontainsContinuedFrom();

	/**
	*/
	public String getContinuedFromType();

	/**
	*/
	public Boolean getContinuedFromHasTypeStringByte();

	/**
	*/
	public Boolean getcontainsContinuedList();

	/**
	*/
	public String getContinuedListType();

	/**
	*/
	public Boolean getContinuedListHasTypeBoolean();

	/**
	*/
	public Boolean getcontainsDesc();

	/**
	*/
	public String getDescType();

	/**
	*/
	public Boolean getDescHasTypeStringText();

	/**
	*/
	public Boolean getcontainsEndIndent();

	/**
	*/
	public String getEndIndentType();

	/**
	*/
	public Boolean getEndIndentHasTypeNumber();

	/**
	*/
	public Boolean getcontainsGlyphOrientationVertical();

	/**
	*/
	public String getGlyphOrientationVerticalType();

	/**
	*/
	public Boolean getGlyphOrientationVerticalHasTypeInteger();

	/**
	*/
	public Boolean getGlyphOrientationVerticalHasTypeName();

	/**
	*/
	public Long getGlyphOrientationVerticalIntegerValue();

	/**
	*/
	public String getGlyphOrientationVerticalNameValue();

	/**
	*/
	public Boolean getcontainsHeaders();

	/**
	*/
	public String getHeadersType();

	/**
	*/
	public Boolean getHeadersHasTypeArray();

	/**
	*/
	public Boolean getcontainsHeight();

	/**
	*/
	public String getHeightType();

	/**
	*/
	public Boolean getHeightHasTypeName();

	/**
	*/
	public Boolean getHeightHasTypeNumber();

	/**
	*/
	public Boolean getcontainsInlineAlign();

	/**
	*/
	public String getInlineAlignType();

	/**
	*/
	public Boolean getInlineAlignHasTypeName();

	/**
	*/
	public String getInlineAlignNameValue();

	/**
	*/
	public Boolean getcontainsLineHeight();

	/**
	*/
	public String getLineHeightType();

	/**
	*/
	public Boolean getLineHeightHasTypeName();

	/**
	*/
	public Boolean getLineHeightHasTypeNumber();

	/**
	*/
	public String getLineHeightNameValue();

	/**
	*/
	public Boolean getcontainsListNumbering();

	/**
	*/
	public String getListNumberingType();

	/**
	*/
	public Boolean getListNumberingHasTypeName();

	/**
	*/
	public String getListNumberingNameValue();

	/**
	*/
	public Boolean getcontainsNS();

	/**
	*/
	public Boolean getisNSIndirect();

	/**
	*/
	public String getNSType();

	/**
	*/
	public Boolean getNSHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsNoteType();

	/**
	*/
	public String getNoteTypeType();

	/**
	*/
	public Boolean getNoteTypeHasTypeName();

	/**
	*/
	public String getNoteTypeNameValue();

	/**
	*/
	public Boolean getcontainsO();

	/**
	*/
	public String getOType();

	/**
	*/
	public Boolean getOHasTypeName();

	/**
	*/
	public String getONameValue();

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public String getPType();

	/**
	*/
	public Boolean getPHasTypeArray();

	/**
	*/
	public Boolean getcontainsPadding();

	/**
	*/
	public String getPaddingType();

	/**
	*/
	public Boolean getPaddingHasTypeArray();

	/**
	*/
	public Boolean getPaddingHasTypeNumber();

	/**
	*/
	public Boolean getcontainsPlacement();

	/**
	*/
	public String getPlacementType();

	/**
	*/
	public Boolean getPlacementHasTypeName();

	/**
	*/
	public String getPlacementNameValue();

	/**
	*/
	public Boolean getcontainsRole();

	/**
	*/
	public String getRoleType();

	/**
	*/
	public Boolean getRoleHasTypeName();

	/**
	*/
	public String getRoleNameValue();

	/**
	*/
	public Boolean getcontainsRowSpan();

	/**
	*/
	public String getRowSpanType();

	/**
	*/
	public Boolean getRowSpanHasTypeInteger();

	/**
	*/
	public Boolean getcontainsRubyAlign();

	/**
	*/
	public String getRubyAlignType();

	/**
	*/
	public Boolean getRubyAlignHasTypeName();

	/**
	*/
	public String getRubyAlignNameValue();

	/**
	*/
	public Boolean getcontainsRubyPosition();

	/**
	*/
	public String getRubyPositionType();

	/**
	*/
	public Boolean getRubyPositionHasTypeName();

	/**
	*/
	public String getRubyPositionNameValue();

	/**
	*/
	public Boolean getcontainsScope();

	/**
	*/
	public String getScopeType();

	/**
	*/
	public Boolean getScopeHasTypeName();

	/**
	*/
	public String getScopeNameValue();

	/**
	*/
	public Boolean getcontainsShort();

	/**
	*/
	public String getShortType();

	/**
	*/
	public Boolean getShortHasTypeStringText();

	/**
	*/
	public Boolean getcontainsSpaceAfter();

	/**
	*/
	public String getSpaceAfterType();

	/**
	*/
	public Boolean getSpaceAfterHasTypeNumber();

	/**
	*/
	public Boolean getcontainsSpaceBefore();

	/**
	*/
	public String getSpaceBeforeType();

	/**
	*/
	public Boolean getSpaceBeforeHasTypeNumber();

	/**
	*/
	public Boolean getcontainsStartIndent();

	/**
	*/
	public String getStartIndentType();

	/**
	*/
	public Boolean getStartIndentHasTypeNumber();

	/**
	*/
	public Boolean getcontainsSubtype();

	/**
	*/
	public String getSubtypeType();

	/**
	*/
	public Boolean getSubtypeHasTypeName();

	/**
	*/
	public String getSubtypeNameValue();

	/**
	*/
	public Boolean getcontainsSummary();

	/**
	*/
	public String getSummaryType();

	/**
	*/
	public Boolean getSummaryHasTypeStringText();

	/**
	*/
	public Boolean getcontainsTBorderStyle();

	/**
	*/
	public String getTBorderStyleType();

	/**
	*/
	public Boolean getTBorderStyleHasTypeArray();

	/**
	*/
	public Boolean getTBorderStyleHasTypeName();

	/**
	*/
	public String getTBorderStyleNameValue();

	/**
	*/
	public Boolean getcontainsTPadding();

	/**
	*/
	public String getTPaddingType();

	/**
	*/
	public Boolean getTPaddingHasTypeArray();

	/**
	*/
	public Boolean getTPaddingHasTypeInteger();

	/**
	*/
	public Boolean getcontainsTextAlign();

	/**
	*/
	public String getTextAlignType();

	/**
	*/
	public Boolean getTextAlignHasTypeName();

	/**
	*/
	public String getTextAlignNameValue();

	/**
	*/
	public Boolean getcontainsTextDecorationColor();

	/**
	*/
	public String getTextDecorationColorType();

	/**
	*/
	public Boolean getTextDecorationColorHasTypeArray();

	/**
	*/
	public Boolean getcontainsTextDecorationThickness();

	/**
	*/
	public String getTextDecorationThicknessType();

	/**
	*/
	public Boolean getTextDecorationThicknessHasTypeNumber();

	/**
	*/
	public Boolean getcontainsTextDecorationType();

	/**
	*/
	public String getTextDecorationTypeType();

	/**
	*/
	public Boolean getTextDecorationTypeHasTypeName();

	/**
	*/
	public String getTextDecorationTypeNameValue();

	/**
	*/
	public Boolean getcontainsTextIndent();

	/**
	*/
	public String getTextIndentType();

	/**
	*/
	public Boolean getTextIndentHasTypeNumber();

	/**
	*/
	public Boolean getcontainsTextPosition();

	/**
	*/
	public String getTextPositionType();

	/**
	*/
	public Boolean getTextPositionHasTypeName();

	/**
	*/
	public String getTextPositionNameValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsWidth();

	/**
	*/
	public String getWidthType();

	/**
	*/
	public Boolean getWidthHasTypeName();

	/**
	*/
	public Boolean getWidthHasTypeNumber();

	/**
	*/
	public Boolean getcontainsWritingMode();

	/**
	*/
	public String getWritingModeType();

	/**
	*/
	public Boolean getWritingModeHasTypeName();

	/**
	*/
	public String getWritingModeNameValue();

	/**
	*/
	public Boolean getcontainschecked();

	/**
	*/
	public String getcheckedType();

	/**
	*/
	public Boolean getcheckedHasTypeName();

	/**
	*/
	public String getcheckedNameValue();
}
